% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cBioDataPack.R
\name{downloadStudy}
\alias{downloadStudy}
\alias{untarStudy}
\alias{loadStudy}
\title{Manually download, untar, and load study tarballs}
\usage{
downloadStudy(
  cancer_study_id,
  use_cache = TRUE,
  force = FALSE,
  url_location = getOption("cBio_URL", .url_location)
)

untarStudy(cancer_study_file, exdir = tempdir())

loadStudy(filepath, names.field = c("Hugo_Symbol", "Entrez_Gene_Id", "Gene"))
}
\arguments{
\item{cancer_study_id}{character(1) The study identifier from cBioPortal as
in \url{https://cbioportal.org/webAPI}}

\item{use_cache}{logical(1) (default TRUE) create the default cache location
and use it to track downloaded data. If data found in the cache, data will
not be re-downloaded. A path can also be provided to data cache location.}

\item{force}{logical(1) (default FALSE) whether to force re-download data from
remote location}

\item{url_location}{character(1)
(default "https://cbioportal-datahub.s3.amazonaws.com") the URL location for
downloading packaged data. Can be set using the 'cBio_URL' option (see
\code{?cBioDataPack} for more details)}

\item{cancer_study_file}{character(1) indicates the on-disk location
of the downloaded tarball}

\item{exdir}{character(1) indicates the folder location to \emph{put}
the contents of the tarball (default \code{tempdir()}; see also \code{?untar})}

\item{filepath}{character(1) indicates the folder location where
the contents of the tarball are \emph{located} (usually the same as \code{exdir})}

\item{names.field}{A character vector of possible column names for the column
that is used to label ranges from a mutations or copy number file.}
}
\value{
\itemize{
\item {downloadStudy - The file location of the data tarball}
\item {untarStudy - The directory location of the contents}
\item {loadStudy - A MultiAssayExperiment-class object}
}
}
\description{
\strong{Note} that these functions should be used when a particular
study is \emph{not} currently available as a \code{MultiAssayExperiment}
representation. Otherwise, use \code{cBioDataPack}. Provide a \code{cancer_study_id}
from the \code{studiesTable} and retrieve the study tarball from cBioPortal.
These functions are used by \code{cBioDataPack} under the hood to download,
untar, and load the tarball datasets with caching. As stated in
\code{?cBioDataPack}, not all studies are currently working as
\code{MultiAssayExperiment} objects. As of July 2020, about ~80\% of
datasets can be successfully imported into the \code{MultiAssayExperiment} data
class. Please open an issue if you would like the team to prioritize a
study. You may also check \code{studiesTable$pack_build} for a more current
status.
}
\examples{

(acc_file <- downloadStudy("acc_tcga"))

(file_dir <- untarStudy(acc_file, tempdir()))

loadStudy(file_dir)

}
\seealso{
\link{cBioDataPack}, \linkS4class{MultiAssayExperiment}
}
